Netlify-cli
===========

Pluggable CLI for Netlify. 🎉

<!-- toc -->
* [Usage](#usage)
* [Local Development](#local-development)
<!-- tocstop -->

# Usage
<!-- usage -->
```sh-session
$ npm install -g netlify-cli
$ netlify-cli COMMAND
running command...
$ netlify-cli (-v|--version|version)
netlify-cli/2.0.0-alpha.2 darwin-x64 node-v10.8.0
$ netlify-cli --help [COMMAND]
USAGE
  $ netlify-cli COMMAND
...
```
<!-- usagestop -->

You can also access the cli from the following aliases:

- `netlify`
- `ntl`

<!-- commands -->
* [`netlify-cli deploy [PUBLISHFOLDER]`](#netlify-cli-deploy-publishfolder)
* [`netlify-cli link`](#netlify-cli-link)
* [`netlify-cli login`](#netlify-cli-login)
* [`netlify-cli logout`](#netlify-cli-logout)
* [`netlify-cli sites`](#netlify-cli-sites)
* [`netlify-cli sites:create`](#netlify-cli-sitescreate)
* [`netlify-cli sites:delete SITEID`](#netlify-cli-sitesdelete-siteid)
* [`netlify-cli sites:list`](#netlify-cli-siteslist)
* [`netlify-cli sites:update`](#netlify-cli-sitesupdate)
* [`netlify-cli sites:watch`](#netlify-cli-siteswatch)
* [`netlify-cli status`](#netlify-cli-status)
* [`netlify-cli unlink`](#netlify-cli-unlink)

## `netlify-cli deploy [PUBLISHFOLDER]`

[36mCreate a new deploy from the contents of a folder.[39m

```
USAGE
  $ netlify-cli deploy [PUBLISHFOLDER]

ARGUMENTS
  PUBLISHFOLDER  folder to deploy (optional)

OPTIONS
  --functions=functions
```

_See code: [src/commands/deploy/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/deploy/index.js)_

## `netlify-cli link`

[36mLink a local repo or project folder to an existing site on Netlify[39m

```
USAGE
  $ netlify-cli link

OPTIONS
  --force
  --id=id
  --name=name

EXAMPLES
  $ netlify init --id 123-123-123-123
  $ netlify init --name my-site-name
```

_See code: [src/commands/link/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/link/index.js)_

## `netlify-cli login`

[36mLogin to account[39m

```
USAGE
  $ netlify-cli login
```

_See code: [src/commands/login/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/login/index.js)_

## `netlify-cli logout`

[36mLogout of account[39m

```
USAGE
  $ netlify-cli logout
```

_See code: [src/commands/logout/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/logout/index.js)_

## `netlify-cli sites`

[36mHandle site operations[39m

```
USAGE
  $ netlify-cli sites

DESCRIPTION
  The sites command will help you manage all your sites

EXAMPLES
  $ netlify sites:create --name my-new-site
  $ netlify sites:update --name my-new-site
  $ netlify sites:delete --name my-new-site
  $ netlify sites:list
```

_See code: [src/commands/sites/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/index.js)_

## `netlify-cli sites:create`

create a site

```
USAGE
  $ netlify-cli sites:create

OPTIONS
  -n, --name=name  name to print

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src/commands/sites/create/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/create/index.js)_

## `netlify-cli sites:delete SITEID`

delete a site

```
USAGE
  $ netlify-cli sites:delete SITEID

ARGUMENTS
  SITEID  Site ID to delete

OPTIONS
  -n, --name=name  name to print

DESCRIPTION
  ...
  Extra documentation goes here

EXAMPLE
  $ netlify site:delete 123-432621211
```

_See code: [src/commands/sites/delete/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/delete/index.js)_

## `netlify-cli sites:list`

list sites

```
USAGE
  $ netlify-cli sites:list

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src/commands/sites/list/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/list/index.js)_

## `netlify-cli sites:update`

update a site

```
USAGE
  $ netlify-cli sites:update

OPTIONS
  -n, --name=name  name to print

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src/commands/sites/update/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/update/index.js)_

## `netlify-cli sites:watch`

Watch for site deploy to finish

```
USAGE
  $ netlify-cli sites:watch

DESCRIPTION
  ...
  Extra documentation goes here
```

_See code: [src/commands/sites/watch/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/sites/watch/index.js)_

## `netlify-cli status`

[36mPrint currently logged in use[39m

```
USAGE
  $ netlify-cli status
```

_See code: [src/commands/status/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/status/index.js)_

## `netlify-cli unlink`

[36mUnlink a local repo from a Netlify site[39m

```
USAGE
  $ netlify-cli unlink
```

_See code: [src/commands/unlink/index.js](https://github.com/netlify/cli/blob/v2.0.0-alpha.2/src/commands/unlink/index.js)_
<!-- commandsstop -->

---
<details>
  <summary>Notes from previous CLIs</summary>

This CLI supercedes our [old Go CLI](https://github.com/netlify/netlifyctl) and [old Node CLI](https://github.com/netlify/netlify-cli).

**Go CLI commands**

via https://github.com/netlify/netlifyctl

```
Available Commands:
  assets    # List assets attached to a site
  ├── add   # Add an asset to a site
  └── info  # Show information for an asset or a group of them
  deploy    # Deploy your site
  form      # List forms
  └── submissions # list form submissions
  help      # Help about any command
  init      # Configure continuous deployment
  login     # Log user in
  site      # Handle site operations
  ├── create   # create site
  └── update   # Update site settings
  version
```

**Node CLI Commands**

via https://github.com/netlify/netlify-cli

```
createSite = require("../lib/commands/create_site"),
deleteSite = require("../lib/commands/delete_site"),
deploy     = require("../lib/commands/deploy"),
publish    = require("../lib/commands/publish"),
init       = require("../lib/commands/init"),
list       = require("../lib/commands/list_sites"),
updateSite = require("../lib/commands/update_site"),
openSite   = require("../lib/commands/open"),
env        = require("../lib/commands/env"),
```

</details>


**Misc examples**

- https://github.com/feinoujc/gh-search-cli/blob/master/src/commands/code.ts#L16-L53
- https://github.com/oclif/plugin-plugins#what-is-this

# Local Development

1. Clone down the repo

```command
$ git clone git@github.com:netlify/cli.git
```

2. Install dependencies

```command
$ npm install
```

3. Run CLI locally during development

```command
$ ./bin/run [command]
```

When developing, you can use watch mode which will automatically rebuild the cli and run tests with ava:

```command
$ npm run watch
```
